@@ -2,16 +2,23 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import sale
-from . import stock
+
+from . import account, party, sale, stock
+from .stock import ShipmentCostSaleMixin
+
+__all__ = ['register', 'ShipmentCostSaleMixin']
 
 
 def register():
     Pool.register(
+        party.Party,
+        party.PartySaleMethod,
+        account.InvoiceLine,
         sale.Configuration,
         sale.ConfigurationSaleMethod,
         sale.Sale,
         sale.Line,
+        stock.ShipmentCostSale,
         stock.ShipmentOut,
         module='sale_shipment_cost', type_='model')
     Pool.register(
